@@ -3,13 +3,13 @@ from Products.CMFPlone.interfaces import IPropertiesTool
 from collective.contentleadimage import config
 
 def importVarious(self):
+    if self.readDataFile('contentleadimage.txt') is None:
+        return
+
     portal = self.getSite()
     ptool = getToolByName(portal, 'portal_properties')
     props = ptool.cli_properties
 
-    if self.readDataFile('contentleadimage.txt') is None:
-        return
-        
     if not props.hasProperty('image_width'):
         props.manage_addProperty('image_width', config.IMAGE_SCALE_SIZE[0], 'int')
     if not props.hasProperty('image_height'):
@@ -19,4 +19,8 @@ def importVarious(self):
     if not props.hasProperty('body_scale_name'):
         props.manage_addProperty('body_scale_name', 'mini', 'string')
     
-    
\ No newline at end of file
+def removeConfiglet(self):
+    if self.readDataFile('cli-uninstall.txt') is None:
+        return
+    portal_conf=getToolByName(self.getSite(),'portal_controlpanel')
+    portal_conf.unregisterConfiglet('ContentLeadImage')
\ No newline at end of file
